@@ -22,6 +22,7 @@ COMMAND_TEMPLATE = 'command.jinja2'
 DB_PORT_TEMPLATE = 'db_port.jinja2'
 USE_CASE_PORT_TEMPLATE = 'use_case_port.jinja2'
 USE_CASE_TEMPLATE = 'use_case.jinja2'
+EXCEPTION_TEMPLATE = 'exception.jinja2'
 
 # DOMAIN FRAGMENTS
 DOM_FIELD = 'field.jinja2'
@@ -50,6 +51,7 @@ PROCESS_COMMAND = 'process_command.jinja2'
 CONTROLLER_TEMPLATE = 'controller.jinja2'
 CONTROLLER_WITH_MAP_TEMPLATE = 'controller_w_map.jinja2'
 REST_MODEL_TEMPLATE = 'model.jinja2'
+EXCEPTION_HANDLER_TEMPLATE = 'api_exception_handler.jinja2'
 
 # REST FRAGMENTS
 REST_FIELD = 'field.jinja2'
