@@ -2,9 +2,9 @@ from pathlib import Path
 from typing import Optional, Tuple, Dict
 
 from crudhex.domain.models import Entity
-from .generation_commons import create_class, create_shared_class
+from .generation_commons import create_class, create_shared_class, create_common_class
 from crudhex.domain.services.config_context import get_config
-from crudhex.domain.services.rest import controller_generator, model_generator, mapper_generator
+from crudhex.domain.services.rest import controller_generator, model_generator, mapper_generator, exception_handler_generator
 from ..models.mapper import MapperType
 
 
@@ -23,3 +23,8 @@ def create_mapper_class(entities_map: Dict[str, Entity], mapper_type: MapperType
                         override: bool = False, folder: Optional[Path] = None):
     return create_shared_class(mapper_generator, entities_map, mapper_type,
                                override=override, folder=folder, default_folder=Path(get_config().get_rest_mapper_path()))
+
+
+def create_exception_handler_class(override: bool = False, folder: Optional[Path] = None):
+    return create_common_class(exception_handler_generator, override=override, folder=folder,
+                               default_folder=Path(get_config().get_rest_exception_handler_path()))
